=======
Credits
=======

Development Lead
----------------

* Emilio Cartoni <emilio.cartoni@yahoo.it>
* Francesco Mannella <francesco.mannella@gmail.com>
* S.P. Mohanty <mohanty@aicrowd.com>

Contributors
------------

None yet. Why not be the first?
